@@ -3,10 +3,15 @@
 """
 Classes used both by front-end and back-end
 """
+import logging
 import os.path
+import platform
+import site
+import sys
 import tokenize
 from collections import namedtuple
 from typing import List, Optional  # @UnusedImport
+import subprocess
 
 MESSAGE_MARKER = "\x02"
 
@@ -248,6 +253,77 @@ def read_source(filename):
         return fp.read()
 
 
+def get_exe_dirs():
+    result = []
+    if site.ENABLE_USER_SITE:
+        if platform.system() == "Windows":
+            if site.getusersitepackages():
+                result.append(site.getusersitepackages()
+                              .replace("site-packages", "Scripts"))
+        else:
+            if site.getuserbase():
+                result.append(site.getuserbase() + "/bin")
+    
+    main_scripts = os.path.join(sys.prefix, "Scripts")
+    if os.path.isdir(main_scripts) and main_scripts not in result:
+        result.append(main_scripts)
+    
+    if os.path.dirname(sys.executable) not in result:
+        result.append(os.path.dirname(sys.executable))
+    
+    return result
+
+def get_site_dir(symbolic_name, executable=None):
+    if not executable or executable == sys.executable:
+        result = getattr(site, symbolic_name, "")
+    else:
+        result = subprocess.check_output(
+            [executable, '-m', 'site', 
+                '--' + symbolic_name.lower().replace("_", "-")],
+            universal_newlines=True
+        ).decode().strip()
+    
+    return result if result else None
+
+def get_base_executable():
+    if sys.exec_prefix == sys.base_exec_prefix:
+        return sys.executable
+    
+    if platform.system() == "Windows":
+        result = sys.base_exec_prefix + "\\" + os.path.basename(sys.executable)
+        result = normpath_with_actual_case(result)
+    else:
+        result = sys.executable.replace(sys.exec_prefix, sys.base_exec_prefix)
+    
+    if not os.path.isfile(result):
+        raise RuntimeError("Can't locate base executable")
+    
+    return result
+
+def get_augmented_system_path(extra_dirs):
+    path_items = os.environ.get("PATH", "").split(os.pathsep)
+    
+    for d in reversed(extra_dirs):
+        if d not in path_items:
+            path_items.insert(0, d)
+    
+    return os.pathsep.join(path_items)
+
+def update_system_path(env, value):
+    # in Windows, env keys are not case sensitive
+    # this is important if env is a dict (not os.environ)
+    if platform.system() == "Windows":
+        found = False
+        for key in env:
+            if key.upper() == "PATH":
+                found = True
+                env[key] = value
+        
+        if not found:
+            env["PATH"] = value
+    else:
+        env["PATH"] = value
+
 class UserError(RuntimeError):
     """Errors of this class are meant to be presented without stacktrace"""
 
