@@ -100,11 +100,13 @@ class ConfigurationPage(ttk.Frame):
         ttk.Frame.__init__(self, master)
 
     def add_checkbox(
-        self, flag_name, description, row=None, column=0, pady=0, columnspan=1, tooltip=None
+        self, flag_name, description, row=None, column=0, 
+        padx=0, pady=0, columnspan=1, tooltip=None
     ):
         variable = get_workbench().get_variable(flag_name)
         checkbox = ttk.Checkbutton(self, text=description, variable=variable)
-        checkbox.grid(row=row, column=column, sticky=tk.W, pady=pady, columnspan=columnspan)
+        checkbox.grid(row=row, column=column, sticky=tk.W, 
+                      padx=padx, pady=pady, columnspan=columnspan)
 
         if tooltip is not None:
             ui_utils.create_tooltip(checkbox, tooltip)
@@ -121,6 +123,13 @@ class ConfigurationPage(ttk.Frame):
         )
         combobox.grid(row=row, column=column, sticky=tk.W, pady=pady, columnspan=columnspan)
 
+    
+    def add_entry(self, option_name,  row=None, column=0, pady=0, padx=0, columnspan=1, **kw):
+        variable = get_workbench().get_variable(option_name)
+        entry = ttk.Entry(self, textvariable=variable, **kw)
+        entry.grid(row=row, column=column, sticky=tk.W, pady=pady, 
+                   columnspan=columnspan, padx=padx)
+
     def apply(self):
         """Apply method should return False, when page contains invalid
         input and configuration dialog should not be closed."""
