@@ -303,7 +303,10 @@ class FrameVisualizer:
         self._line_debug = frame_info.current_statement is None
 
         self._reconfigure_tags()
-
+    
+    def _translate_lineno(self, lineno):
+        return lineno - self._firstlineno + 1
+        
     def _reconfigure_tags(self):
         for tag in ["active_focus", "exception_focus"]:
             conf = get_syntax_options_for_tag(tag).copy()
@@ -365,13 +368,15 @@ class FrameVisualizer:
         self._remove_focus_tags()
 
         if frame_info.event == "line":
-            if frame_info.id in msg["exception_info"]["affected_frame_ids"]:
+            if (frame_info.id in msg["exception_info"]["affected_frame_ids"]
+                and msg["exception_info"]["is_fresh"]):
                 self._tag_range(frame_info.focus, "exception_focus")
             else:
                 self._tag_range(frame_info.focus, "active_focus")
         else:
             if "statement" in frame_info.event:
-                if msg["exception_info"]["msg"] is not None:
+                if (msg["exception_info"]["msg"] is not None
+                    and msg["exception_info"]["is_fresh"]):
                     stmt_tag = "exception_focus"
                 elif frame_info.event.startswith("before"):
                     stmt_tag = "active_focus"
@@ -385,10 +390,13 @@ class FrameVisualizer:
 
         self._expression_box.update_expression(msg, frame_info)
 
-        if frame_info.id in msg["exception_info"]["affected_frame_ids"]:
+        if (frame_info.id in msg["exception_info"]["affected_frame_ids"] 
+            and msg["exception_info"]["is_fresh"]):
             self._show_exception(
                 msg["exception_info"]["lines_with_frame_info"], frame_info
             )
+        else:
+            self.close_note()
 
     def _show_exception(self, lines, frame_info):
         last_line_text = lines[-1][0]
@@ -413,17 +421,17 @@ class FrameVisualizer:
         # but for pseudo-statements (like header in for-loop) I want to highlight only the indicated range
 
         line_prefix = self._text.get(
-            "%d.0" % text_range.lineno,
-            "%d.%d" % (text_range.lineno, text_range.col_offset),
+            "%d.0" % self._translate_lineno(text_range.lineno),
+            "%d.%d" % (self._translate_lineno(text_range.lineno), text_range.col_offset),
         )
         if line_prefix.strip():
             # pseudo-statement
-            first_line = text_range.lineno
-            last_line = text_range.end_lineno
+            first_line = self._translate_lineno(text_range.lineno)
+            last_line = self._translate_lineno(text_range.end_lineno)
             self._text.tag_add(
                 tag,
-                "%d.%d" % (text_range.lineno, text_range.col_offset),
-                "%d.%d" % (text_range.end_lineno, text_range.end_col_offset),
+                "%d.%d" % (first_line, text_range.col_offset),
+                "%d.%d" % (last_line, text_range.end_col_offset),
             )
         else:
             # normal statement
@@ -575,7 +583,8 @@ class ExpressionBox(tk.Text):
                 self._highlight_range(
                     focus,
                     event,
-                    frame_info.id in msg["exception_info"]["affected_frame_ids"],
+                    (frame_info.id in msg["exception_info"]["affected_frame_ids"]
+                     and msg["exception_info"]["is_fresh"]),
                 )
 
             self._update_position(frame_info.current_root_expression)
@@ -1019,7 +1028,7 @@ def _start_debug_enabled():
     return (
         _current_debugger is None
         and get_workbench().get_editor_notebook().get_current_editor() is not None
-        and "debug" in get_runner().supported_features()
+        and "debug" in get_runner().get_supported_features()
     )
 
 
@@ -1058,13 +1067,27 @@ class DebuggerConfigurationPage(ConfigurationPage):
             "debugger.single_window",
             "Use editors and Stack view for presenting call frames",
             tooltip="Presents the concept of stack like most professional IDE-s",
+            row=1,
+            columnspan=3
         )
         self.add_checkbox(
             "debugger.automatic_stack_view",
             "Open and close Stack view automatically",
             tooltip="Opens the Stack view on first call and "
             + "closes it when program returns to main frame.",
+            row=2,
+            columnspan=3
         )
+        
+        if get_workbench().get_option("run.birdseye_port", None):
+            port_label = ttk.Label(self, text="Birdseye port", anchor="w")
+            port_label.grid(row=3, column=0, sticky="w", pady=5)
+            self.add_entry("run.birdseye_port", row=3, column=1, width=5, pady=15, padx=5)
+            comment_label = ttk.Label(self, text="(restart Thonny after changing this)", anchor="w")
+            comment_label.grid(row=3, column=2, sticky="w", pady=5)
+            
+        self.columnconfigure(2, weight=1)
+        
 
 
 def get_current_debugger():
